# Copyright 2013 Mario Graff (https://github.com/mgraffg)

# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#     http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""b4msa extends our work on creating a text classifier (specifically
:py:class:`microtc.textmodel.TextModel`) by incorporating different
language dependant techniques.

The starting point is :py:class:`b4msa.textmodel.TextModel`
"""
__version__ = "2.2.0"
